BeagleBoardPkg: The FDF file does not reserve any more the area for the OMAP35xxx header

It is the tool BeagleBoardPkg/Tools/generate_image which will add a CH header to a the
BeagleBoard FD file.

The build macro EDK2_SECOND_STAGE_BOOTOLADER is not required any more.



git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@12433 6f19259b-4bc3-4df7-8a09-765794883524
diff --git a/BeagleBoardPkg/BeagleBoardPkg-next.fdf b/BeagleBoardPkg/BeagleBoardPkg-next.fdf
index cc8f3b0..0b0cef0 100755
--- a/BeagleBoardPkg/BeagleBoardPkg-next.fdf
+++ b/BeagleBoardPkg/BeagleBoardPkg-next.fdf
@@ -48,14 +48,7 @@
 # RegionType <FV, DATA, or FILE>
 #
 ################################################################################
-!if $(EDK2_SECOND_STAGE_BOOTOLADER) == 1
 0x00000000|0x00080000
-!else
-# 512 bytes of configuration header & 8 bytes of image header
-0x00000000|0x00000208
-
-0x00000208|0x0007FDF8
-!endif
 gArmTokenSpaceGuid.PcdFvBaseAddress|gArmTokenSpaceGuid.PcdFvBaseSize
 FV = FVMAIN_COMPACT
 
@@ -182,7 +175,6 @@
   INF ArmPlatformPkg/Bds/Bds.inf
 
 
-
 [FV.FVMAIN_COMPACT]
 FvAlignment        = 8
 ERASE_POLARITY     = 1
diff --git a/BeagleBoardPkg/BeagleBoardPkg.fdf b/BeagleBoardPkg/BeagleBoardPkg.fdf
index c6aa87a..f265b7d 100644
--- a/BeagleBoardPkg/BeagleBoardPkg.fdf
+++ b/BeagleBoardPkg/BeagleBoardPkg.fdf
@@ -27,7 +27,6 @@
 
 
 [FD.BeagleBoard_EFI]
-####BaseAddress   = 0x80208000|gEmbeddedTokenSpaceGuid.PcdEmbeddedFdBaseAddress  #The base address of the FLASH Device.
 BaseAddress   = 0x80008000|gEmbeddedTokenSpaceGuid.PcdEmbeddedFdBaseAddress  #The base address of the FLASH Device.
 Size          = 0x00080000|gEmbeddedTokenSpaceGuid.PcdEmbeddedFdSize         #The size in bytes of the FLASH Device
 ErasePolarity = 1
@@ -49,15 +48,8 @@
 # RegionType <FV, DATA, or FILE>
 #
 ################################################################################
-!if $(EDK2_SECOND_STAGE_BOOTOLADER) == 1
 0x00000000|0x00080000
-!else
-# 512 bytes of configuration header & 8 bytes of image header
-0x00000000|0x00000208
-
-0x00000208|0x0007FDF8
-!endif
-gEmbeddedTokenSpaceGuid.PcdFlashFvMainBase|gEmbeddedTokenSpaceGuid.PcdFlashFvMainSize
+gArmTokenSpaceGuid.PcdFvBaseAddress|gArmTokenSpaceGuid.PcdFvBaseSize
 FV = FVMAIN_COMPACT
 
 ################################################################################
diff --git a/BeagleBoardPkg/Tools/generate_image.c b/BeagleBoardPkg/Tools/generate_image.c
index 6ac9268..fa4cdcc 100644
--- a/BeagleBoardPkg/Tools/generate_image.c
+++ b/BeagleBoardPkg/Tools/generate_image.c
@@ -316,7 +316,6 @@
   FILE         *InputFile;
   FILE         *OutputFile;
   unsigned int InputImageFileSize;
-  unsigned int NewImageFileSize;
   struct       stat FileStat;
   char         Ch;
   unsigned int i;
@@ -327,31 +326,25 @@
     exit(0);
   } 
 
-  //Get the size of the input image.
+  // Get the size of the input image.
   fstat(fileno(InputFile), &FileStat);
   InputImageFileSize = FileStat.st_size;
   
-  //Calculate new file size
-  NewImageFileSize = InputImageFileSize - 520;
-
   OutputFile = fopen(gOutputImageFile, "wb");
   if (OutputFile == NULL) {
     fprintf(stderr, "Can't open output file %s.\n", gOutputImageFile);
     exit(0);
   }
 
-  //Write Configuration header 
+  // Write Configuration header 
   fwrite(gConfigurationHeader, 1, sizeof(gConfigurationHeader), OutputFile);
 
-  //Write image header (Input image size, execution address)
-  fwrite(&NewImageFileSize, 1, 4, OutputFile);
+  // Write image header (Input image size, execution address)
+  fwrite(&InputImageFileSize, 1, 4, OutputFile);
   fwrite(&gImageExecutionAddress, 1, 4, OutputFile);
 
-  //Skip first 0x207 bytes
-  fseek(InputFile, 520, SEEK_SET);
-
-  //Copy input image to the output file.
-  for (i = 0; i < NewImageFileSize; i++) {
+  // Copy input image to the output file.
+  for (i = 0; i < InputImageFileSize; i++) {
     fread(&Ch, 1, 1, InputFile);
     fwrite(&Ch, 1, 1, OutputFile);
   }
diff --git a/BeagleBoardPkg/build.sh b/BeagleBoardPkg/build.sh
index 6f48ebd..3ce923e 100755
--- a/BeagleBoardPkg/build.sh
+++ b/BeagleBoardPkg/build.sh
@@ -132,12 +132,12 @@
 
 #
 # Ram starts at 0x80000000
 # OMAP 3530 TRM defines 0x80008208 as the entry point
 # The reset vector is caught by the mask ROM in the OMAP 3530 so that is why this entry 
 # point looks so strange. 
 # OMAP 3430 TRM section 26.4.8 has Image header information. (missing in OMAP 3530 TRM)
 #
-$GENERATE_IMAGE -D $WORKSPACE/BeagleBoardPkg/ConfigurationHeader.dat -E 0x80008208 -I $BUILD_ROOT/FV/BEAGLEBOARD_EFI.fd -O $FLASH_BOOT
+$GENERATE_IMAGE -D $WORKSPACE/BeagleBoardPkg/ConfigurationHeader.dat -E 0x80008000 -I $BUILD_ROOT/FV/BEAGLEBOARD_EFI.fd -O $FLASH_BOOT
 
 echo Creating debugger scripts
 process_debug_scripts $WORKSPACE/BeagleBoardPkg/Debugger_scripts
@@ -132,12 +132,12 @@
 #
 # Ram starts at 0x80000000
-# OMAP 3530 TRM defines 0x80008208 as the entry point
+# OMAP 3530 TRM defines 0x80008000 as the entry point
 # The reset vector is caught by the mask ROM in the OMAP 3530 so that is why this entry 
 # point looks so strange. 